==> scummvm_0.13.0-1.tar.gz: scummvm-0.13.0/engines/parallaction/saveload.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-13-0/engines/parallaction/saveload.h $
 * $Id: saveload.h 34221 2008-08-31 08:27:40Z peres001 $
 *
 */


#ifndef PARALLACTION_SAVELOAD_H
#define PARALLACTION_SAVELOAD_H

namespace Parallaction {

struct Character;


class SaveLoad {

protected:
	Common::SaveFileManager	*_saveFileMan;
	Common::String _saveFilePrefix;

	Common::String genSaveFileName(uint slot);
	Common::InSaveFile *getInSaveFile(uint slot);
	Common::OutSaveFile *getOutSaveFile(uint slot);

public:
	SaveLoad(Common::SaveFileManager* saveFileMan, const char *prefix) : _saveFileMan(saveFileMan), _saveFilePrefix(prefix) { }
	virtual ~SaveLoad() { }

	virtual bool loadGame() = 0;
	virtual bool saveGame() = 0;
	virtual void getGamePartProgress(bool *complete, int size) = 0;
	virtual void setPartComplete(const char *part) = 0;

	virtual void renameOldSavefiles() { }
};

class SaveLoad_ns : public SaveLoad {

	Parallaction_ns *_vm;

	Common::String	_saveFileName;
	Common::String genOldSaveFileName(uint slot);

protected:
	void renameOldSavefiles();
	void doLoadGame(uint16 slot);
	void doSaveGame(uint16 slot, const char* name);
	int  buildSaveFileList(Common::StringList& l);
	int  selectSaveFile(uint16 arg_0, const char* caption, const char* button);

public:
	SaveLoad_ns(Parallaction_ns *vm, Common::SaveFileManager *saveFileMan) : SaveLoad(saveFileMan, "nippon"), _vm(vm) { }

	virtual bool loadGame();
	virtual bool saveGame();
	virtual void getGamePartProgress(bool *complete, int size);
	virtual void setPartComplete(const char *part);
};

class SaveLoad_br : public SaveLoad {

	Parallaction_br *_vm;

public:
	SaveLoad_br(Parallaction_br *vm, Common::SaveFileManager *saveFileMan) : SaveLoad(saveFileMan, "bra"), _vm(vm) { }

	virtual bool loadGame();
	virtual bool saveGame();
	virtual void getGamePartProgress(bool *complete, int size);
	virtual void setPartComplete(const char *part);
};


} // namespace Parallaction

#endif

==> scummvm_1.0.0~rc1-1.orig.tar.gz: scummvm-1.0.0rc1/engines/parallaction/saveload.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-0-0rc1/engines/parallaction/saveload.h $
 * $Id: saveload.h 40191 2009-04-29 05:30:58Z peres001 $
 *
 */


#ifndef PARALLACTION_SAVELOAD_H
#define PARALLACTION_SAVELOAD_H

namespace Parallaction {

struct Character;


class SaveLoad {

protected:
	Common::SaveFileManager	*_saveFileMan;
	Common::String _saveFilePrefix;

	Common::String genSaveFileName(uint slot);
	Common::InSaveFile *getInSaveFile(uint slot);
	Common::OutSaveFile *getOutSaveFile(uint slot);
	int selectSaveFile(Common::String &selectedName, const Common::String &caption, const Common::String &button);
	int buildSaveFileList(Common::StringList& l);
	virtual void doLoadGame(uint16 slot) = 0;
	virtual void doSaveGame(uint16 slot, const char* name) = 0;

public:
	SaveLoad(Common::SaveFileManager* saveFileMan, const char *prefix) : _saveFileMan(saveFileMan), _saveFilePrefix(prefix) { }
	virtual ~SaveLoad() { }

	virtual bool loadGame();
	virtual bool saveGame();

	virtual void getGamePartProgress(bool *complete, int size) = 0;
	virtual void setPartComplete(const char *part) = 0;

	virtual void renameOldSavefiles() { }
};

class SaveLoad_ns : public SaveLoad {

	Parallaction_ns *_vm;
	Common::String genOldSaveFileName(uint slot);

protected:
	void renameOldSavefiles();
	virtual void doLoadGame(uint16 slot);
	virtual void doSaveGame(uint16 slot, const char* name);

public:
	SaveLoad_ns(Parallaction_ns *vm, Common::SaveFileManager *saveFileMan) : SaveLoad(saveFileMan, "nippon"), _vm(vm) { }

	virtual bool saveGame();

	virtual void getGamePartProgress(bool *complete, int size);
	virtual void setPartComplete(const char *part);
};

class SaveLoad_br : public SaveLoad {

	Parallaction_br *_vm;
	virtual void doLoadGame(uint16 slot);
	virtual void doSaveGame(uint16 slot, const char* name);

public:
	SaveLoad_br(Parallaction_br *vm, Common::SaveFileManager *saveFileMan) : SaveLoad(saveFileMan, "bra"), _vm(vm) { }

	virtual void getGamePartProgress(bool *complete, int size);
	virtual void setPartComplete(const char *part);
};


} // namespace Parallaction

#endif
